@@ -45,6 +45,8 @@ MainWindow::MainWindow(QWidget *parent) :
         printf("Unable to load WAV file: %s\n", Mix_GetError());
     }
 
+    // Connects
+    connect(ui->action_Quit, SIGNAL(triggered()), this, SLOT(close()));
     connect(ui->horizontalSlider, SIGNAL(valueChanged(int)), this, SLOT(onSliderChanged(int)));
     connect(ui->pushButton, SIGNAL(clicked()), this, SLOT(onBtnClick()));
     connect(timer_, SIGNAL(timeout()), this, SLOT(onTimeout()));
